@@ -668,7 +668,10 @@ class SingleDagRunJob(BaseJob, SingletonContext):
                 ti.state == State.UPSTREAM_FAILED
                 and task_run.task_run_state != TaskRunState.UPSTREAM_FAILED
             ):
-                task_run.set_task_run_state(TaskRunState.UPSTREAM_FAILED, track=False)
+                state = databand_run.get_upstream_failed_task_run_state(task_run)
+
+                logger.info("Setting %s to %s", task_run.task.task_id, state)
+                task_run.set_task_run_state(state, track=False)
                 task_runs.append(task_run)
             # update only in memory state
             if (
@@ -871,7 +874,7 @@ def report_airflow_task_instance(
             af_instances.append(af_instance)
 
     if airflow_config is None:
-        airflow_config = AirflowConfig.current()
+        airflow_config = AirflowConfig.from_databand_context()
 
     if af_instances and airflow_config.webserver_url:
         first_task_run = task_runs[0]
